@@ -251,7 +251,6 @@
 # Main function for expected power --------------------------------------------
 exppower.TOST <- function(alpha = 0.05, logscale = TRUE, theta0, theta1, theta2, 
                           CV, n, design = "2x2", robust = FALSE, 
-                          dfCV, # to be removed in next versions,
                           prior.type = c("CV", "theta0", "both"),
                           prior.parm = list(),
                           method = c("exact", "approx")) {
@@ -312,12 +311,6 @@ exppower.TOST <- function(alpha = 0.05, logscale = TRUE, theta0, theta1, theta2,
   # Based on information in nms_match derive degrees of freedom and 
   # standard error of prior trial
   df_m <- sem_m <- NA
-  if (!missing(dfCV)) {  # Temporary code for dfCV
-    warning(paste0("Argument dfCV has been moved to component df of argument ", 
-                   "prior.parm and will not function in the next versions."), 
-            call. = FALSE)
-    df_m <- dfCV[[1]]
-  }
   if (sum(nms_match[3:4]) == 2) {  # m and design given
     if (prior.parm$design == "parallel" && design != "parallel")
       stop(paste0("CV in case of parallel design is total variability. This ",
